@@ -4,13 +4,13 @@ __doc__ = "Module for getting/modifying data models in Odoo"
 
 class Odoo():
   def __init__(self) -> None:
-    self.url = 'https://little-unicorn.odoo.com'
-    self.db = 'little-unicorn'
-    self.models = xmlrpc.client.ServerProxy('{}/xmlrpc/2/object'.format(self.url))
-    self.username = 'bbrandley@littleunicorn.com'
-    self.password = "4Od0024!"
-    self.common = xmlrpc.client.ServerProxy('{}/xmlrpc/2/common'.format(self.url))
-    self.uid = self.common.authenticate(self.db, self.username, self.password, {})
+    # self.url = 'https://little-unicorn.odoo.com'
+    # self.db = 'little-unicorn'
+    # self.models = xmlrpc.client.ServerProxy('{}/xmlrpc/2/object'.format(self.url))
+    # self.username = 'bbrandley@littleunicorn.com'
+    # self.password = "4Od0024!"
+    # self.common = xmlrpc.client.ServerProxy('{}/xmlrpc/2/common'.format(self.url))
+    # self.uid = self.common.authenticate(self.db, self.username, self.password, {})
 
   def getObject(self, object, id):
     obj = self.models.execute_kw(self.db, self.uid, self.password, object, 'read', [id])
